import React, {Component} from "react";
import {Button, Form, Input, Steps, Row, Col} from "antd";
import './Form.less'
import {LockOutlined, MailOutlined, SecurityScanOutlined, UserOutlined} from "@ant-design/icons";

const {Step} = Steps;

class ForgetPasswordForm extends Component {
    state = {
        forgetStatus: 'check',
        currentStep: 0,
        stepProcessStatus: 'process',
    }

    handleCheckSuccessfully = () => {
        this.setState({
            forgetStatus: 'confirm',
            currentStep: 1,
        })
    }

    handleConfirmSuccessfully = () => {
        this.setState({
            forgetStatus: 'reset',
            currentStep: 2,
        })
    }

    render() {
        let {forgetStatus, currentStep, stepProcessStatus} = this.state;

        return (
            <Row>
                <Col span={8}>
                    <Steps direction="vertical" size={'small'} current={currentStep} status={stepProcessStatus}>
                        <Step title="Check Identity"/>
                        <Step title="Confirm Code"/>
                        <Step title="Reset Password"/>
                    </Steps>
                </Col>
                <Col span={16}>
                    {
                        forgetStatus === 'check' ?
                            <Form onSubmit={this.handleSubmitLogin} className="forget-password-form"
                                  initialValues={{remember: true}}>
                                <Form.Item
                                    name="account"
                                    rules={[{required: true, message: 'Please input your Username!'}]}
                                >
                                    <Input
                                        prefix={<UserOutlined className="site-form-item-icon"/>}
                                        placeholder="Username"
                                        size="large"
                                    />
                                </Form.Item>
                                <Form.Item
                                    name="email"
                                    rules={[
                                        {
                                            type: 'email',
                                            message: 'The input is not valid E-mail!',
                                        },
                                        {
                                            required: true,
                                            message: 'Please input your E-mail!',
                                        },
                                    ]}
                                >
                                    <Input
                                        prefix={<MailOutlined className="site-form-item-icon"/>}
                                        placeholder="E-mail"
                                        size="large"
                                    />
                                </Form.Item>
                                <Form.Item style={{marginBottom: '10px'}}>
                                    <Button size="large" type="primary" htmlType="submit" className="login-form-button"
                                            style={{width: '100%'}} onClick={this.handleCheckSuccessfully}>
                                        RESET YOUR PASSWORD
                                    </Button>
                                </Form.Item>
                                <Form.Item style={{marginBottom: '0'}}>
                                    <Button type="link" block style={{textAlign: 'right'}} onClick={() => {
                                        this.props.handleLoginStatus('login')
                                    }}>
                                        LOGIN
                                    </Button>
                                </Form.Item>
                            </Form> : forgetStatus === 'confirm' ?
                                <Form onSubmit={this.handleSubmitLogin} className="forget-password-form"
                                      initialValues={{remember: true}}>
                                    <Form.Item
                                        name="VerificationCode"
                                        rules={[{required: true, message: 'Please input your Verification Code!'}]}
                                    >
                                        <Input
                                            prefix={<SecurityScanOutlined className="site-form-item-icon"/>}
                                            placeholder="Verification Code"
                                            size="large"
                                        />
                                    </Form.Item>
                                    <Form.Item style={{marginBottom: '10px'}}>
                                        <Button size="large" type="primary" htmlType="submit" className="login-form-button"
                                                style={{width: '100%'}} onClick={this.handleConfirmSuccessfully}>
                                            CONFIRM
                                        </Button>
                                    </Form.Item>
                                </Form> :
                                <Form onSubmit={this.handleSubmitLogin} className="forget-password-form"
                                      initialValues={{remember: true}}>
                                    <Form.Item
                                        name="password"
                                        rules={[
                                            {
                                                required: true,
                                                message: 'Please input your password!',
                                            },
                                        ]}
                                        hasFeedback
                                    >
                                        <Input.Password placeholder="Password"
                                                        prefix={<LockOutlined className="site-form-item-icon"/>}
                                                        size="large"
                                        />
                                    </Form.Item>
                                    <Form.Item
                                        name="confirm"
                                        dependencies={['password']}
                                        hasFeedback
                                        rules={[
                                            {
                                                required: true,
                                                message: 'Please confirm your password!',
                                            },
                                            ({getFieldValue}) => ({
                                                validator(_, value) {
                                                    if (!value || getFieldValue('password') === value) {
                                                        return Promise.resolve();
                                                    }
                                                    return Promise.reject(new Error('The two passwords that you entered do not match!'));
                                                },
                                            }),
                                        ]}
                                    >
                                        <Input.Password prefix={<LockOutlined className="site-form-item-icon"/>}
                                                        placeholder="Confirm Password"
                                                        size="large"
                                        />
                                    </Form.Item>
                                    <Form.Item style={{marginBottom: '10px'}}>
                                        <Button size="large" type="primary" htmlType="submit" className="login-form-button"
                                                style={{width: '100%'}}>
                                            RESET PASSWORD
                                        </Button>
                                    </Form.Item>
                                </Form>
                    }
                </Col>
            </Row>
        )
    }
}

export default ForgetPasswordForm;