import React, {Component} from "react";
import {Table, Tag, Space} from 'antd';
import {FileTextOutlined, FolderOpenOutlined} from "@ant-design/icons";

const columns = [
    {
        title: 'Type',
        dataIndex: 'type',
        key: 'type',
        width: '15%',
        render: text => {
            if (text === 'file') {
                return (
                    <div>
                        <FileTextOutlined/>
                        &nbsp; FILE
                    </div>
                )
            } else if (text === 'folder') {
                return (
                    <div>
                        <FolderOpenOutlined/>
                        &nbsp; FOLDER
                    </div>
                )
            }
        }
    },
    {
        title: 'Name',
        dataIndex: 'name',
        key: 'name',
        render: (text, record) => {
            if (record.type === 'file') {
                return (
                    <div>
                        {text}
                    </div>
                )
            } else {
                return (
                    <a>{text}</a>
                )
            }
        },
    },
    {
        title: 'Tags',
        key: 'tags',
        dataIndex: 'tags',
        render: tags => (
            <>
                {tags.map(tag => {
                    let color = tag.length > 5 ? 'geekblue' : 'green';
                    if (tag === 'loser') {
                        color = 'volcano';
                    }
                    return (
                        <Tag color={color} key={tag}>
                            {tag.toUpperCase()}
                        </Tag>
                    );
                })}
            </>
        ),
    },
    {
        title: 'Action',
        key: 'action',
        render: (text, record) => {
            if (record.type === 'file') {
                return (
                    <Space size="middle">
                        <a>Download {record.name}</a>
                        <a>Delete</a>
                    </Space>
                )
            } else {
                return (
                    <a>Get In</a>
                )
            }
        }
    },
];

const data = [
    {
        key: '1',
        type: 'file',
        name: '高等数学',
        tags: ['nice', 'developer'],
    },
    {
        key: '2',
        type: 'file',
        name: 'Jim Green',
        tags: ['loser'],
    },
    {
        key: '3',
        type: 'folder',
        name: 'Joe Black',
        tags: ['cool', 'teacher'],
    },
    {
        key: '3',
        type: 'folder',
        name: 'Joe Black',
        tags: ['cool', 'teacher'],
    },
    {
        key: '3',
        type: 'folder',
        name: 'Joe Black',
        tags: ['cool', 'teacher'],
    },
    {
        key: '3',
        type: 'folder',
        name: 'Joe Black',
        tags: ['cool', 'teacher'],
    },
    {
        key: '3',
        type: 'folder',
        name: 'Joe Black',
        tags: ['cool', 'teacher'],
    },
    {
        key: '3',
        type: 'folder',
        name: 'Joe Black',
        tags: ['cool', 'teacher'],
    },
    {
        key: '3',
        type: 'folder',
        name: 'Joe Black',
        tags: ['cool', 'teacher'],
    },
    {
        key: '3',
        type: 'folder',
        name: 'Joe Black',
        tags: ['cool', 'teacher'],
    },

];

class DiskPage extends Component {
    render() {
        return (
            <Table columns={columns} dataSource={data}/>
        )
    }
}

export default DiskPage;